Mozilla Developer Network

# Welcome to django-valet-keys’s documentation!

django-valet-keys is a Django app for managing valet keys to let robots drive around in your identity.

- Build status on travis-ci ()
- Latest documentation on Read The Docs (source)
- Task board on Huboard (source)

Contents:

- Overview
  - What is django-valet-keys?
- Getting Started
  - Installation
  - Configuration
- Usage
  - Views included
  - The `@accepts_valet_key` decorator
  - The `Key` model and activity logging

# Indices and tables

- Index
- Search Page

Is MDN helpful to you? Please share your feedback with us. Or join our mailing list about improving MDN content.